@@ -11,8 +11,8 @@ ls
 pwd
 find .
 
-set PACKAGE_PATTERN="*pdal*.conda"
-if [[ -n `find . -name $PACKAGE_PATTERN` ]]; then
+export PACKAGE_PATTERN="*pdal*.conda"
+if [[ -n `find . -name "*pdal*.conda"` ]]; then
     echo "Found packages to upload"
 else
     echo "No packages matching $PACKAGE_PATTERN to upload were found"
