@@ -10,7 +10,6 @@ LDFLAGS="$LDFLAGS -Wl,-rpath-link,$CONDA_PREFIX/lib" cmake .. \
       -DCMAKE_INCLUDE_PATH:FILEPATH="$CONDA_PREFIX/include" \
       -DCMAKE_BUILD_TYPE=Debug \
       -DCMAKE_INSTALL_PREFIX=${CONDA_PREFIX} \
-      -DBUILD_PLUGIN_I3S=ON \
       -DBUILD_PLUGIN_NITF=ON \
       -DBUILD_PLUGIN_TILEDB=ON \
       -DBUILD_PLUGIN_ARROW=ON \
@@ -19,6 +18,7 @@ LDFLAGS="$LDFLAGS -Wl,-rpath-link,$CONDA_PREFIX/lib" cmake .. \
       -DBUILD_PLUGIN_HDF=ON \
       -DBUILD_PLUGIN_PGPOINTCLOUD=ON \
       -DBUILD_PLUGIN_E57=ON \
+      -DBUILD_PLUGIN_SPZ=ON \
       -DBUILD_PGPOINTCLOUD_TESTS=OFF \
       -DWITH_ZSTD=ON \
       -DWITH_ZLIB=ON \
