@@ -44,6 +44,7 @@
 #include <filters/ReprojectionFilter.hpp>
 #include <filters/SortFilter.hpp>
 #include <pdal/SrsBounds.hpp>
+#include <pdal/private/OGRSpec.hpp>
 #include <pdal/util/FileUtils.hpp>
 #include <pdal/private/gdal/GDALUtils.hpp>
 
@@ -184,7 +185,7 @@ TEST(CopcReaderTest, boundedRead2d)
 {
     BOX2D bounds(515380, 4918350, 515400, 4918370);
 
-    // First we'll query the EptReader for these bounds.
+    // First we'll query the CopcReader for these bounds.
     CopcReader reader;
     {
         Options options;
@@ -243,7 +244,7 @@ TEST(CopcReaderTest, boundedRead3d)
 {
     BOX3D bounds(515380, 4918350, 2320, 515400, 4918370, 2325);
 
-    // First we'll query the EptReader for these bounds.
+    // First we'll query the CopcReader for these bounds.
     CopcReader reader;
     {
         Options options;
@@ -370,12 +371,8 @@ TEST(CopcReaderTest, stream)
     const std::size_t numPoints(normalView.size());
     const std::size_t pointSize(normalTable.layout()->pointSize());
 
-    const auto cmp = [](const PointRef& a, const PointRef& b)
-    {
-        return (a.compare(Dimension::Id::GpsTime, b));
-    };
-    std::sort(normalView.begin(), normalView.end(), cmp);
-    std::sort(streamView.begin(), streamView.end(), cmp);
+    normalView.sort(Dimension::Id::GpsTime);
+    streamView.sort(Dimension::Id::GpsTime);
 
     for (PointId i(0); i < normalView.size(); ++i)
         for (const auto& dim : normalTable.layout()->dims())
@@ -388,12 +385,12 @@ TEST(CopcReaderTest, stream)
         }
 }
 
-TEST(EptReaderTest, boundedCrop)
+TEST(CopcReaderTest, boundedCrop)
 {
     std::string wkt = FileUtils::readFileIntoString(
         Support::datapath("autzen/autzen-selection.wkt"));
 
-    // First we'll query the EptReader for these bounds.
+    // First we'll query the CopcReader for these bounds.
     CopcReader reader;
     {
         Options options;
@@ -435,12 +432,12 @@ TEST(EptReaderTest, boundedCrop)
 }
 
 
-TEST(EptReaderTest, boundedCropGeoJSON)
+TEST(CopcReaderTest, boundedCropGeoJSON)
 {
     std::string wkt = FileUtils::readFileIntoString(
         Support::datapath("autzen/autzen-selection.json"));
 
-    // First we'll query the EptReader for these bounds.
+    // First we'll query the CopcReader for these bounds.
     CopcReader reader;
     {
         Options options;
@@ -618,10 +615,12 @@ TEST(CopcReaderTest, ogrCrop)
 {
     const std::string srs = R"(PROJCS["NAD_1983_HARN_Lambert_Conformal_Conic",GEOGCS["GCS_North_American_1983_HARN",DATUM["NAD83_High_Accuracy_Reference_Network",SPHEROID["GRS 1980",6378137,298.2572221010002,AUTHORITY["EPSG","7019"]],AUTHORITY["EPSG","6152"]],PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433]],PROJECTION["Lambert_Conformal_Conic_2SP"],PARAMETER["standard_parallel_1",43],PARAMETER["standard_parallel_2",45.5],PARAMETER["latitude_of_origin",41.75],PARAMETER["central_meridian",-120.5],PARAMETER["false_easting",1312335.958005249],PARAMETER["false_northing",0],UNIT["foot",0.3048,AUTHORITY["EPSG","9002"]]])";
 
-    NL::json ogr;
-    ogr["drivers"] = {"GeoJSON"};
-    ogr["datasource"] = Support::datapath("autzen/attributes.json");
-    ogr["sql"] = "select \"_ogr_geometry_\" from attributes";
+    NL::json json;
+    json["type"] = "ogr";
+    json["drivers"] = {"GeoJSON"};
+    json["datasource"] = Support::datapath("autzen/attributes.json");
+    json["sql"] = "select \"_ogr_geometry_\" from attributes";
+    OGRSpec ogr(json);
 
     CopcReader reader;
     {
@@ -648,7 +647,7 @@ TEST(CopcReaderTest, ogrCrop)
         source.setOptions(options);
     }
 
-    std::vector<Polygon> polys = gdal::getPolygons(ogr);
+    std::vector<Polygon> polys = ogr.getPolygons();
     for (Polygon& p : polys)
         p.transform(srs);
     PointTable sourceTable;
@@ -674,4 +673,69 @@ TEST(CopcReaderTest, ogrCrop)
     EXPECT_LE(v->size(), 90u);
 }
 
+
+TEST(CopcReaderTest, boundedpreview)
+{
+
+
+    BOX2D bounds(515380, 4918350, 515400, 4918370);
+
+    CopcReader reader;
+    {
+        Options options;
+        options.add("filename", copcPath);
+        options.add("bounds", bounds);
+        reader.setOptions(options);
+    }
+
+    pdal::QuickInfo qi(reader.preview());
+    pdal::BOX3D bounds3d = qi.m_bounds;
+
+    EXPECT_EQ(pdal::Bounds(bounds).to2d(), pdal::Bounds(bounds3d).to2d());
+}
+
+void testURLs(const std::string& url, const BOX2D& bounds)
+{
+
+    CopcReader reader;
+    {
+        Options options;
+        options.add("bounds", bounds);
+        options.add("filename", url);
+        options.add("resolution", 1000);
+
+        reader.setOptions(options);
+    }
+
+    pdal::QuickInfo qi(reader.preview());
+    EXPECT_EQ(61201, qi.m_pointCount);
+
+    pdal::BOX3D bounds3d = qi.m_bounds;
+    EXPECT_EQ(pdal::Bounds(bounds).to2d(), pdal::Bounds(bounds3d).to2d());
+
+}
+
+
+TEST(CopcReaderTest, vsi)
+{
+
+    /*
+          "maxx": 639003.73,
+          "maxy": 853534.37,
+          "maxz": 615.26,
+          "minx": 635579.2,
+          "miny": 848887.49,
+          "minz": 406.56
+    */
+
+    BOX2D bounds(635700,848900, 637000, 853300);
+    std::string url( "https://github.com/PDAL/data/raw/refs/heads/main/autzen/autzen-classified.copc.laz");
+    std::string vsi ("/vsicurl/"+url);
+
+    testURLs(url, bounds);
+    testURLs(vsi, bounds);
+
+
+}
+
 } // namespace pdal
